[otrs-cvs] otrs/Kernel/System/CustomerUser LDAP.pm,1.73,1.74

"CVS commits notifications of OTRS.org" <[email protected]>
Newsgroups gmane.comp.otrs.cvs
Message-ID <[email protected]>
Comments:
Update of /home/cvs/otrs/Kernel/System/CustomerUser
In directory lancelot:/tmp/cvs-serv15410/Kernel/System/CustomerUser

Modified Files:
	LDAP.pm 
Log Message:
s/seperator/separator/gi

Author: mb

Index: LDAP.pm
===================================================================
RCS file: /home/cvs/otrs/Kernel/System/CustomerUser/LDAP.pm,v
retrieving revision 1.73
retrieving revision 1.74
diff -2 -u -d -r1.73 -r1.74
--- LDAP.pm	16 Jan 2013 15:47:15 -0000	1.73
+++ LDAP.pm	17 Jan 2013 07:22:56 -0000	1.74
@@ -673,12 +673,12 @@
     if ( $Data{UserCustomerIDs} ) {
 
-        # used seperators
-        SEPERATOR:
-        for my $Seperator ( ';', ',', '|' ) {
+        # used separators
+        separator:
+        for my $separator ( ';', ',', '|' ) {
 
-            next SEPERATOR if $Data{UserCustomerIDs} !~ /\Q$Seperator\E/;
+            next separator if $Data{UserCustomerIDs} !~ /\Q$separator\E/;
 
             # split it
-            my @IDs = split /\Q$Seperator\E/, $Data{UserCustomerIDs};
+            my @IDs = split /\Q$separator\E/, $Data{UserCustomerIDs};
 
             for my $ID (@IDs) {
@@ -688,8 +688,8 @@
             }
 
-            last SEPERATOR;
+            last separator;
         }
 
         # fallback if no seperator got found
         if ( !@CustomerIDs ) {
             $Data{UserCustomerIDs} =~ s/^\s+//g;
---------------------------------------------------------------------
@@ -688,8 +688,8 @@
         }
 
-        # fallback if no seperator got found
+        # fallback if no separator got found
         if ( !@CustomerIDs ) {
             $Data{UserCustomerIDs} =~ s/^\s+//g;
OTRS mailing list: cvs-log - Webpage: http://otrs.org/
Archive: http://lists.otrs.org/pipermail/cvs-log
To unsubscribe: http://lists.otrs.org/cgi-bin/listinfo/cvs-log
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.